# Statistics for Meggie

Adds permutation tests to all three core pipelines (spetrums, evoked analysis and induced analysis) of Meggie.

## Installation:

1. Activate the meggie environment
1. Install: python -m pip install meggie\_statistics

## Usage:

If everything went fine, meggie should now recognize the plugin and you can enable it from the settings.

